@@ -1,35 +1,12 @@
-/** ===========================================================
- * @file
- *
- * This file is a part of KDE project
- *
- *
- * @date   2004-02-01
- * @brief  plugin loader
- *
- * @author Copyright (C) 2004-2018 by Gilles Caulier
- *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
- * @author Copyright (C) 2004-2005 by Renchi Raju
- *         <a href="mailto:renchi dot raju at gmail dot com">renchi dot raju at gmail dot com</a>
- * @author Copyright (C) 2009      by Andi Clemens
- *         <a href="mailto:andi dot clemens at googlemail dot com">andi dot clemens at googlemail dot com</a>
- * @author Copyright (C) 2009      by Aleix Pol Gonzalez
- *         <a href="mailto:aleixpol at kde dot org">aleixpol at kde dot org</a>
- * @author Copyright (C) 2012-2013 by Victor Dodon
- *         <a href="mailto:dodonvictor at gmail dot com">dodonvictor at gmail dot com</a>
- *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * ============================================================ */
+/*
+    SPDX-FileCopyrightText: 2004-2018 Gilles Caulier <caulier dot gilles at gmail dot com>
+    SPDX-FileCopyrightText: 2004-2005 Renchi Raju <renchi dot raju at gmail dot com>
+    SPDX-FileCopyrightText: 2009 Andi Clemens <andi dot clemens at googlemail dot com>
+    SPDX-FileCopyrightText: 2009 Aleix Pol Gonzalez <aleixpol at kde dot org>
+    SPDX-FileCopyrightText: 2012-2013 Victor Dodon <dodonvictor at gmail dot com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "pluginloader.h"
 
@@ -41,15 +18,15 @@
 #include <QAction>
 #include <QStandardPaths>
 
-// KDE includes
+// KF includes
 
-#include <kservicetypetrader.h>
-#include <ksharedconfig.h>
-#include <kdesktopfile.h>
-#include <kconfiggroup.h>
-#include <kxmlguifactory.h>
-#include <ktoolbar.h>
-#include <kactioncollection.h>
+#include <KServiceTypeTrader>
+#include <KSharedConfig>
+#include <KDesktopFile>
+#include <KConfigGroup>
+#include <KXMLGUIFactory>
+#include <KToolBar>
+#include <KActionCollection>
 
 // Local includes
 
@@ -70,8 +47,8 @@ public:
     Private()
     {
         shouldLoad = false;
-        plugin     = 0;
-        parent     = 0;
+        plugin     = nullptr;
+        parent     = nullptr;
     }
 
     bool           shouldLoad;
@@ -94,14 +71,14 @@ PluginLoader::Info::~Info()
     {
         d->parent->guiFactory()->removeClient(d->plugin);
 
-        foreach(KToolBar* const toolbar, d->parent->toolBars())
+        const auto toolBars = d->parent->toolBars();
+        for (KToolBar* const toolbar : toolBars)
         {
             toolbar->removeXMLGUIClient(d->plugin);
         }
     }
 
     delete d->plugin;
-    delete d;
 }
 
 KService::Ptr PluginLoader::Info::service() const
@@ -165,7 +142,7 @@ Plugin* PluginLoader::Info::plugin() const
         {
             qCDebug(LIBKIPI_LOG) << "Loaded plugin " << d->plugin->objectName();
 
-            emit (PluginLoader::instance()->plug(const_cast<Info*>(this)));
+            Q_EMIT (PluginLoader::instance()->plug(const_cast<Info*>(this)));
         }
         else
         {
@@ -191,14 +168,15 @@ void PluginLoader::Info::reload()
     {
         d->parent->guiFactory()->removeClient(d->plugin);
 
-        foreach(KToolBar* const toolbar, d->parent->toolBars())
+        const auto toolBars = d->parent->toolBars();
+        for (KToolBar* const toolbar : toolBars)
         {
             toolbar->removeXMLGUIClient(d->plugin);
         }
     }
 
     delete d->plugin;
-    d->plugin = 0;
+    d->plugin = nullptr;
 }
 
 bool PluginLoader::Info::shouldLoad() const
@@ -213,7 +191,7 @@ void PluginLoader::Info::setShouldLoad(bool value)
 
 //---------------------------------------------------------------------
 
-static PluginLoader* s_instance = 0;
+static PluginLoader* s_instance = nullptr;
 static bool          s_loaded   = false;
 
 class Q_DECL_HIDDEN PluginLoader::Private
@@ -222,9 +200,9 @@ public:
 
     Private()
     {
-        interface = 0;
-        parent    = 0;
-    };
+        interface = nullptr;
+        parent    = nullptr;
+    }
 
     QStringList              ignoredPlugins;
     QStringList              disabledActions;
@@ -238,14 +216,14 @@ public:
 PluginLoader::PluginLoader()
     : d(new Private)
 {
-    Q_ASSERT((s_instance == 0) && (!s_loaded));
+    Q_ASSERT((s_instance == nullptr) && (!s_loaded));
     s_instance = this;
 }
 
 PluginLoader::PluginLoader(KXmlGuiWindow* const parent)
     : d(new Private)
 {
-    Q_ASSERT((s_instance == 0) && (!s_loaded));
+    Q_ASSERT((s_instance == nullptr) && (!s_loaded));
     s_instance = this;
 
     if (!parent)
@@ -279,7 +257,7 @@ QStringList PluginLoader::disabledPluginActions() const
 
 void PluginLoader::init()
 {
-    Q_ASSERT((s_instance != 0) && (!s_loaded));
+    Q_ASSERT((s_instance != nullptr) && (!s_loaded));
 
     if (!d->interface)
     {
@@ -348,14 +326,11 @@ void PluginLoader::init()
     }
 }
 
-PluginLoader::~PluginLoader()
-{
-    delete d;
-}
+PluginLoader::~PluginLoader() = default;
 
 void PluginLoader::loadPlugins()
 {
-    emit replug(); // added for convenience, now they can be loaded on demand
+    Q_EMIT replug(); // added for convenience, now they can be loaded on demand
 }
 
 const PluginLoader::PluginList& PluginLoader::pluginList()
